==> shinken_1.4.orig.tar.gz: shinken-1.4/test/test_servicedependency_complexes.py <==
#!/usr/bin/env python
# Copyright (C) 2009-2010:
#    Gabes Jean, naparuba@gmail.com
#    Gerhard Lausser, Gerhard.Lausser@consol.de
#
# This file is part of Shinken.
#
# Shinken is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Shinken is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Shinken.  If not, see <http://www.gnu.org/licenses/>.

#
# This file is used to test reading and processing of config files
#

from shinken_test import *


class TestConfig(ShinkenTest):

    def setUp(self):
        self.setup_with_file('etc/nagios_servicedependency_complexes.cfg')

    def test_dummy(self):
        #
        # Config is not correct because of a wrong relative path
        # in the main config file
        #
        for s in self.sched.services:
            print s.get_full_name()
        NRPE = self.sched.services.find_srv_by_name_and_hostname("myspecifichost", "NRPE")
        self.assert_(NRPE is not None)
        Load = self.sched.services.find_srv_by_name_and_hostname("myspecifichost", "Load")
        self.assert_(Load is not None)
        print Load.act_depend_of
        self.assert_(NRPE in [e[0] for e in Load.act_depend_of])


if __name__ == '__main__':
    unittest.main()

==> shinken_2.0.3.orig.tar.gz: shinken-2.0.3/test/test_servicedependency_complexes.py <==
#!/usr/bin/env python
# Copyright (C) 2009-2010:
#    Gabes Jean, naparuba@gmail.com
#    Gerhard Lausser, Gerhard.Lausser@consol.de
#
# This file is part of Shinken.
#
# Shinken is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Shinken is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with Shinken.  If not, see <http://www.gnu.org/licenses/>.

#
# This file is used to test reading and processing of config files
#

from shinken_test import *


class TestConfig(ShinkenTest):

    def setUp(self):
        self.setup_with_file('etc/shinken_servicedependency_complexes.cfg')

    def test_dummy(self):
        #
        # Config is not correct because of a wrong relative path
        # in the main config file
        #
        for s in self.sched.services:
            print s.get_full_name()
        NRPE = self.sched.services.find_srv_by_name_and_hostname("myspecifichost", "NRPE")
        self.assert_(NRPE is not None)
        Load = self.sched.services.find_srv_by_name_and_hostname("myspecifichost", "Load")
        self.assert_(Load is not None)
        print Load.act_depend_of
        self.assert_(NRPE in [e[0] for e in Load.act_depend_of])


if __name__ == '__main__':
    unittest.main()
